#!/bin/bash

export ENTRYPOINT_CONF_VERSION=v5

assets() {
  export OTP_SECRET=$(cat /run/secrets/otp_secret)
  export SECRET_KEY_BASE=$(cat /run/secrets/secret_key_base)
  export DB_PASS=$(cat /run/secrets/db_password)

  RAILS_ENV=production bundle exec rails assets:precompile
}

migrate() {
  export OTP_SECRET=$(cat /run/secrets/otp_secret)
  export SECRET_KEY_BASE=$(cat /run/secrets/secret_key_base)
  export DB_PASS=$(cat /run/secrets/db_password)

  bundle exec rake db:setup
}

admin() {
  export OTP_SECRET=$(cat /run/secrets/otp_secret)
  export SECRET_KEY_BASE=$(cat /run/secrets/secret_key_base)
  export DB_PASS=$(cat /run/secrets/db_password)

  tootctl accounts create "$1" --email "$2" --confirmed --role admin
}

secrets() {
  docker context use default > /dev/null 2>&1

  echo "Generating secrets for new Hometown deployment..."
  echo ""

  SECRET_KEY_BASE=$(docker run --rm tootsuite/mastodon:v3.4.0 bundle exec rake secret)
  abra app secret insert "$APP_NAME" secret_key_base v1 "$SECRET_KEY_BASE"
  echo "SECRET_KEY_BASE = $SECRET_KEY_BASE"
  echo ""

  OTP_SECRET=$(docker run --rm tootsuite/mastodon:v3.4.0 bundle exec rake secret)
  abra app secret insert "$APP_NAME" otp_secret v1 "$OTP_SECRET"
  echo "OTP_SECRET = $OTP_SECRET"
  echo ""

  docker run \
    -e SECRET_KEY_BASE="$SECRET_KEY_BASE" \
    -e OTP_SECRET="$OTP_SECRET" \
    --rm tootsuite/mastodon:v3.4.0 \
    bundle exec rake mastodon:webpush:generate_vapid_key \
    > /tmp/key.txt

  VAPID_PRIVATE_KEY=$(grep -oP "VAPID_PRIVATE_KEY=\K.+" "/tmp/key.txt")
  VAPID_PUBLIC_KEY=$(grep -oP "VAPID_PUBLIC_KEY=\K.+" "/tmp/key.txt")
  rm -rf /tmp/key.txt

  echo "VAPID_PUBLIC_KEY = $VAPID_PUBLIC_KEY"
  echo "!IMPORTANT! you MUST insert this VAPID_PUBLIC_KEY into your app .env config !IMPORTANT!"
  echo ""

  abra app secret insert "$APP_NAME" vapid_private_key v1 "$VAPID_PRIVATE_KEY"
  echo "VAPID_PRIVATE_KEY = $VAPID_PRIVATE_KEY"
  echo ""

  abra app secret generate "$APP_NAME" db_password v1
  echo ""

  echo "don't forget to insert your smtp_password! your deployment won't work without it"
  echo "run \"abra app secret insert $APP_NAME smtp_password v1 YOURSMTPPASSWORD\""
  echo ""
}
